Stan Math Library: std::numeric_limits< stan::math::var > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | Static Public Attributes | List of all members
std::numeric_limits< stan::math::var > Struct Template Reference

Specialization of numeric limits for var objects. More...

`#include <std_numeric_limits.hpp>`

## Static Public Member Functions
static stan::math::var | min ()
static stan::math::var | max ()
static stan::math::var | epsilon ()
static stan::math::var | round_error ()
static stan::math::var | infinity ()
static stan::math::var | quiet_NaN ()
static stan::math::var | signaling_NaN ()
static stan::math::var | denorm_min ()

## Static Public Attributes
static const bool | is_specialized = true
static const int | digits = numeric_limits<double>::digits
static const int | digits10 = numeric_limits<double>::digits10
static const bool | is_signed = numeric_limits<double>::is_signed
static const bool | is_integer = numeric_limits<double>::is_integer
static const bool | is_exact = numeric_limits<double>::is_exact
static const int | radix = numeric_limits<double>::radix
static const int | min_exponent = numeric_limits<double>::min_exponent
static const int | min_exponent10 = numeric_limits<double>::min_exponent10
static const int | max_exponent = numeric_limits<double>::max_exponent
static const int | max_exponent10 = numeric_limits<double>::max_exponent10
static const bool | has_infinity = numeric_limits<double>::has_infinity
static const bool | has_quiet_NaN = numeric_limits<double>::has_quiet_NaN
static const bool | has_signaling_NaN = numeric_limits<double>::has_signaling_NaN
static const float_denorm_style | has_denorm = numeric_limits<double>::has_denorm
static const bool | has_denorm_loss = numeric_limits<double>::has_denorm_loss
static const bool | is_iec559 = numeric_limits<double>::is_iec559
static const bool | is_bounded = numeric_limits<double>::is_bounded
static const bool | is_modulo = numeric_limits<double>::is_modulo
static const bool | traps = numeric_limits<double>::traps
static const bool | tinyness_before = numeric_limits<double>::tinyness_before
static const float_round_style | round_style = numeric_limits<double>::round_style

## Detailed Description

### template<>
struct std::numeric_limits< stan::math::var >

Specialization of numeric limits for var objects.

This implementation of std::numeric_limits<stan::math::var> is used to treat var objects like doubles.

Definition at line 16 of file std_numeric_limits.hpp.

## Member Function Documentation

static stan::math::var std::numeric_limits< stan::math::var >::denorm_min | ( |  | ) |
| inlinestatic

Definition at line 54 of file std_numeric_limits.hpp.

static stan::math::var std::numeric_limits< stan::math::var >::epsilon | ( |  | ) |
| inlinestatic

Definition at line 26 of file std_numeric_limits.hpp.

static stan::math::var std::numeric_limits< stan::math::var >::infinity | ( |  | ) |
| inlinestatic

Definition at line 45 of file std_numeric_limits.hpp.

static stan::math::var std::numeric_limits< stan::math::var >::max | ( |  | ) |
| inlinestatic

Definition at line 19 of file std_numeric_limits.hpp.

static stan::math::var std::numeric_limits< stan::math::var >::min | ( |  | ) |
| inlinestatic

Definition at line 18 of file std_numeric_limits.hpp.

static stan::math::var std::numeric_limits< stan::math::var >::quiet_NaN | ( |  | ) |
| inlinestatic

Definition at line 48 of file std_numeric_limits.hpp.

static stan::math::var std::numeric_limits< stan::math::var >::round_error | ( |  | ) |
| inlinestatic

Definition at line 29 of file std_numeric_limits.hpp.

static stan::math::var std::numeric_limits< stan::math::var >::signaling_NaN | ( |  | ) |
| inlinestatic

Definition at line 51 of file std_numeric_limits.hpp.

## Member Data Documentation

const int std::numeric_limits< stan::math::var >::digits = numeric_limits<double>::digits
| static

Definition at line 20 of file std_numeric_limits.hpp.

const int std::numeric_limits< stan::math::var >::digits10 = numeric_limits<double>::digits10
| static

Definition at line 21 of file std_numeric_limits.hpp.

const float_denorm_style std::numeric_limits< stan::math::var >::has_denorm = numeric_limits<double>::has_denorm
| static

Definition at line 43 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::has_denorm_loss = numeric_limits<double>::has_denorm_loss
| static

Definition at line 44 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::has_infinity = numeric_limits<double>::has_infinity
| static

Definition at line 38 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::has_quiet_NaN = numeric_limits<double>::has_quiet_NaN
| static

Definition at line 39 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::has_signaling_NaN = numeric_limits<double>::has_signaling_NaN
| static

Definition at line 41 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::is_bounded = numeric_limits<double>::is_bounded
| static

Definition at line 59 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::is_exact = numeric_limits<double>::is_exact
| static

Definition at line 24 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::is_iec559 = numeric_limits<double>::is_iec559
| static

Definition at line 58 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::is_integer = numeric_limits<double>::is_integer
| static

Definition at line 23 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::is_modulo = numeric_limits<double>::is_modulo
| static

Definition at line 60 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::is_signed = numeric_limits<double>::is_signed
| static

Definition at line 22 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::is_specialized = true
| static

Definition at line 17 of file std_numeric_limits.hpp.

const int std::numeric_limits< stan::math::var >::max_exponent = numeric_limits<double>::max_exponent
| static

Definition at line 35 of file std_numeric_limits.hpp.

const int std::numeric_limits< stan::math::var >::max_exponent10 = numeric_limits<double>::max_exponent10
| static

Definition at line 36 of file std_numeric_limits.hpp.

const int std::numeric_limits< stan::math::var >::min_exponent = numeric_limits<double>::min_exponent
| static

Definition at line 33 of file std_numeric_limits.hpp.

const int std::numeric_limits< stan::math::var >::min_exponent10 = numeric_limits<double>::min_exponent10
| static

Definition at line 34 of file std_numeric_limits.hpp.

const int std::numeric_limits< stan::math::var >::radix = numeric_limits<double>::radix
| static

Definition at line 25 of file std_numeric_limits.hpp.

const float_round_style std::numeric_limits< stan::math::var >::round_style = numeric_limits<double>::round_style
| static

Definition at line 65 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::tinyness_before = numeric_limits<double>::tinyness_before
| static

Definition at line 63 of file std_numeric_limits.hpp.

const bool std::numeric_limits< stan::math::var >::traps = numeric_limits<double>::traps
| static

Definition at line 62 of file std_numeric_limits.hpp.

The documentation for this struct was generated from the following file:

- stan/math/rev/core/std_numeric_limits.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.